# passport-sdk

#### 介绍
{**以下是码云平台说明，您可以替换此简介**
码云是 OSCHINA 推出的基于 Git 的代码托管平台（同时支持 SVN）。专为开发者提供稳定、高效、安全的云端软件开发协作平台
无论是个人、团队、或是企业，都能够用码云实现代码托管、项目管理、协作开发。企业项目请看 [https://gitee.com/enterprises](https://gitee.com/enterprises)}

#### 软件架构
软件架构说明


#### 安装教程

1.  xxxx
2.  xxxx
3.  xxxx

#### 使用说明

1.  xxxx
2.  xxxx
3.  xxxx

#### 参与贡献

1.  Fork 本仓库
2.  新建 Feat_xxx 分支
3.  提交代码
4.  新建 Pull Request


#### 码云特技

1.  使用 Readme\_XXX.md 来支持不同的语言，例如 Readme\_en.md, Readme\_zh.md
2.  码云官方博客 [blog.gitee.com](https://blog.gitee.com)
3.  你可以 [https://gitee.com/explore](https://gitee.com/explore) 这个地址来了解码云上的优秀开源项目
4.  [GVP](https://gitee.com/gvp) 全称是码云最有价值开源项目，是码云综合评定出的优秀开源项目
5.  码云官方提供的使用手册 [https://gitee.com/help](https://gitee.com/help)
6.  码云封面人物是一档用来展示码云会员风采的栏目 [https://gitee.com/gitee-stars/](https://gitee.com/gitee-stars/)


#### 模块打包

1. 项目根目录下新建一个简单的示例client.py文件
```
class Client(object):
    """
    测试客户
    """
    def __init__(self):
        print("my client")

client = Client()
```

2. 项目根目录下新建setup.py文件

3. setup.py文件内容如下
```
from distutils.core import setup

setup(
    name='PassportSdk',#需要打包的名字
    version='v1.0',#版本
    py_modules=['client']#需要打包的模块(文件)
)
```

4. 接下来运行压缩命令,dist目录下生成了最终的压缩包
python setup.py sdist

5. 进入到根目录, 解压
python setup.py install

#### 运行demoapp

```bash
python demoapp/manage.py
```
